@@ -143,7 +143,7 @@ class arg(Argument):
     ```
     class prefixer(Unit):
         @arg('prefix', help='this data will be prepended to the input.')
-        def __init__(self, prefix) -> Unit: pass
+        def __init__(self, prefix): pass
 
         def process(self, data):
             return self.args.prefix + data
@@ -299,11 +299,10 @@ class arg(Argument):
 
         if default is not pt.empty:
             if isinstance(default, (list, tuple)):
+                guessed_kwd_args.setdefault('nargs', ZERO_OR_MORE)
                 if not pt.default:
-                    guessed_kwd_args.setdefault('nargs', ZERO_OR_MORE)
                     default = pt.empty
                 else:
-                    guessed_kwd_args.setdefault('nargs', ONE_OR_MORE)
                     guessed_kwd_args.setdefault('default', pt.default)
                     default = default[0]
             else:
@@ -456,13 +455,27 @@ class Executable(type):
 
     def __new__(mcs, name, bases, nmspc, abstract=False):
         def normalize(operation: Callable[[Any, ByteString], Any]) -> Callable[[ByteString], Any]:
+            def chunkify(item):
+                if not isinstance(item, dict):
+                    return Chunk(item)
+                return Chunk(item.pop('data', None), meta=item)
+
             @wraps(operation)
             def wrapped(self, data: ByteString) -> bytes:
                 if -self.args:
                     if not isinstance(data, bytearray):
                         data = bytearray(data)
                     self.args @= data
-                return operation(self, data)
+                else:
+                    try:
+                        dt = next(iter(operation.__annotations__.values()))
+                        if dt in (bytes, bytearray, memoryview) and not isinstance(data, dt):
+                            data = dt(data)
+                    except StopIteration:
+                        pass
+                if inspect.isgeneratorfunction(operation):
+                    return (chunkify(r) for r in operation(self, data))
+                return chunkify(operation(self, data))
             return wrapped
 
         nmspc.setdefault('__doc__', '')
@@ -498,14 +511,8 @@ class Executable(type):
                     cls.argspec[key] = value.__copy__()
             cls._infer_argspec(parameters, cls.argspec)
 
-        fwd = cls.__init__.__annotations__.get('return', None)
-
-        if fwd is not None and not issubclass(cls, fwd):
-            fwd = None
-        elif cls.__init__.__code__.co_code == (lambda: None).__code__.co_code:
-            fwd = bases[0]
-
-        if fwd is not None:
+        if cls.__init__.__code__.co_code == (lambda: None).__code__.co_code:
+            base = bases[0]
             head = []
             defs = {}
             tail = None
@@ -528,7 +535,7 @@ class Executable(type):
                 for key in defs:
                     if key not in kw:
                         kw[key] = defs[key]
-                fwd.__init__(self, **kw)
+                base.__init__(self, **kw)
 
             cls.__init__ = cls__init__
 
